@@ -2,6 +2,7 @@
 from datetime import date, datetime, timedelta, timezone
 import json
 import os
+import re
 import subprocess
 import sys
 import time
@@ -29,7 +30,14 @@ def compulsory_input(tags, name, example):
         else:
             value = input(tags[0] + name + tags[2])
 
-    return value
+        sanitised = sanitise_input(value, name, tags)
+
+        if len(value) > 0 and (sanitised == "ok" or sanitised == None):
+            return value
+        else:
+            if len(value) > 0 and sanitised != None:
+                print(sanitised)
+            value = ""
 
 
 def digit_input(tags, name, example):
@@ -53,8 +61,108 @@ def yes_no_input(tags, name):
 
 
 def optional_input(tags, name, example):
-    value = input(tags[0] + name + tags[1] + example + tags[2])
-    return value
+
+    incomplete = True
+    while incomplete:
+        value = input(tags[0] + name + tags[1] + example + tags[2])
+        sanitised = sanitise_input(value, name, tags)
+        if len(value) > 0 and (sanitised == "ok" or sanitised == None):
+            incomplete = False
+            return value
+        elif len(value) > 0 and sanitised != None:
+            print(sanitised)
+        else:
+            return ""
+
+
+def sanitise_input(value, input_type, tags):
+    """
+    Check that data entered when running --init complies with requirements
+    """
+
+    if input_type == "Username":
+        return (
+            "Do not include '@' in username, please try again"
+            if value.startswith("@")
+            else "ok"
+        )
+
+    if input_type == "Base URL":
+        error = value.startswith("http") or value.find(".") == -1
+        return (
+            "Provide full domain without protocol prefix (e.g. "
+            + tags[1]
+            + "example.social"
+            + tags[2]
+            + ", not "
+            + tags[1]
+            + "http://example.social"
+            + tags[2]
+            + ")"
+            if error
+            else "ok"
+        )
+
+    if input_type == "Toots to keep":
+        l = value.split(",")
+
+        def check(s):
+            d = s.strip()
+            if not d.isdigit():
+                return False
+
+        allnum = map(check, l)
+        return (
+            "Toot IDs must be numeric and separated with commas"
+            if False in list(allnum)
+            else "ok"
+        )
+
+    if input_type == "Hashtags to keep":
+        l = value.split(",")
+
+        def check(s):
+            d = s.strip()
+            if d.isdigit():
+                return False
+            if not re.fullmatch(r"[\w]+", d, flags=re.IGNORECASE):
+                return False
+
+        complies = map(check, l)
+        return_string = (
+            "Hashtags must not include '#' and must match rules at "
+            + tags[0]
+            + "https://docs.joinmastodon.org/user/posting/#hashtags"
+            + tags[2]
+        )
+        return return_string if False in list(complies) else "ok"
+
+    if input_type == "Visibility to keep":
+        l = value.split(",")
+        viz_options = set(["public", "unlisted", "private", "direct"])
+
+        def check(s):
+            d = [s.strip().lower()]
+            intersects = viz_options.intersection(d)
+            if len(intersects) == 0:
+                return False
+
+        complies = map(check, l)
+        return_string = "Valid values are one or more of 'public', 'unlisted', 'private' or 'direct'"
+        return return_string if False in list(complies) else "ok"
+
+    if input_type == "Archive path":
+        path = (
+            os.path.expanduser(value)
+            if len(str(value)) > 0 and str(value)[0] == "~"
+            else value
+        )
+        response = (
+            "ok"
+            if os.path.exists(path)
+            else "That directory does not exist, please try again"
+        )
+        return response
 
 
 def init():
@@ -151,7 +259,7 @@ def version(vnum):
         print("You are using release: \033[92mv", vnum, "\033[0m", sep="")
         print("The latest release is: \033[92m" + latest_version + "\033[0m")
         print(
-            "To upgrade to the most recent version run \033[92mpip3 install --update ephemetoot\033[0m"
+            "To upgrade to the most recent version run \033[92mpip install --upgrade ephemetoot\033[0m"
         )
 
     except Exception as e:
@@ -437,7 +545,21 @@ def check_batch(config, options, mastodon, user_id, timeline, deleted_count=0):
                 if options.datestamp:
                     print("\n", datestamp_now(), end=" : ")
 
-                print("Removed " + str(deleted_count) + " toots.\n")
+                # options.quiet can be None
+                if (
+                    (not options.quiet)
+                    or options.quiet <= 1
+                    or (options.quiet == 2 and deleted_count)
+                ):
+                    print(
+                        "Removed "
+                        + str(deleted_count)
+                        + " toots for "
+                        + config["username"]
+                        + "@"
+                        + config["base_url"]
+                        + ".\n"
+                    )
 
                 if not options.quiet:
                     print("---------------------------------------")
@@ -463,7 +585,14 @@ def check_batch(config, options, mastodon, user_id, timeline, deleted_count=0):
                     print("---------------------------------------\n")
 
     except IndexError:
-        print("No toots found!\n")
+        if not options.quiet or options.quiet <= 1:
+            print(
+              "No toots found for "
+              + config["username"]
+              + "@"
+              + config["base_url"]
+              + ".\n"
+            )
 
 
 def check_toots(config, options, retry_count=0):
@@ -471,13 +600,14 @@ def check_toots(config, options, retry_count=0):
     The main function, uses the Mastodon API to check all toots in the user timeline, and delete any that do not meet any of the exclusion criteria from the config file.
     """
     try:
-        print(
-            "Fetching account details for @",
-            config["username"],
-            "@",
-            config["base_url"],
-            sep="",
-        )
+        if not options.quiet:
+            print(
+                "Fetching account details for @",
+                config["username"],
+                "@",
+                config["base_url"],
+                sep="",
+            )
 
         if options.pace:
             mastodon = Mastodon(
